An identifier issuer is used to issue new blank node identifier.
Summary
Functions
Issues a new blank node identifier for a given existing blank node identifier.
Functions
Issues a new blank node identifier for a given existing blank node identifier.